<?php
/**
 * Block Spin class
 * 
 * @package Page_Generator_Pro
 * @author  Tim Carr
 * @version 2.0.1
 */
class Page_Generator_Pro_Block_Spin {

    /**
     * Holds the base object.
     *
     * @since   2.0.1
     *
     * @var     object
     */
    public $base;

    /**
     * Constructor.
     *
     * @since   2.0.1
     *
     * @param   object $base    Base Plugin Class
     */
    public function __construct( $base ) {

        // Store base class
        $this->base = $base;

    }

    /**
     * Parses content, which comprises of one or more paragraph (#p /#p) blocks.
     *
     * @since   2.0.1
     *
     * @param   string  $text   Text
     * @return  string          Text
     */
    public function process( $text ) {

        $block = preg_replace_callback(
            "/\#p\#(.*?)\#\/p\#/si",
            array( $this, 'parse_paragraph' ),
            $text
        );

        // Strip all newlines from the block
        // $block = preg_replace( "/\r|\n/", " ", $block );

        // Strip any double spaces
        $block = str_replace( '  ', ' ', $block );

        // Return block
        return $block;

    }

    /**
     * Parses an individual paragraph, which comprises of one or more sentence (#s /#s) blocks.
     *
     * @since   2.0.1
     *
     * @param   array   $matches    preg_match_all matches
     * @return  string              Block Content
     */
    private function parse_paragraph( $matches ) {

        return preg_replace_callback(
            "/\#s\#(.*?)\#\/s\#/s",
            array( $this, 'parse_sentence' ),
            $matches[1]
        );

    }

    /**
     * Parses an individual sentence block, which comprises of one or more lines of
     * sentences.
     *
     * @since   2.0.1
     *
     * @param   array   $matches    preg_match_all matches
     * @return  string              Sentence Content
     */
    private function parse_sentence( $matches ) {

        // Explode the sentence spins
        $parts = explode( "\n", trim( $matches[1] ) );

        // Remove empty sentences, and reindex
        $parts = array_values( array_filter( $parts ) );

        // Return a random sentence from the available options
        return $parts[ array_rand( $parts ) ];

    }

}